summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--source3/nsswitch/winbindd_dual.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/nsswitch/winbindd_dual.c b/source3/nsswitch/winbindd_dual.c
index 6324de9a2d..26debd2674 100644
--- a/source3/nsswitch/winbindd_dual.c
+++ b/source3/nsswitch/winbindd_dual.c
@@ -573,8 +573,8 @@ void winbind_msg_online(int msg_type, struct process_id src,
winbindd_flush_negative_conn_cache(domain);
set_domain_online_request(domain);
- /* Send an offline message to the idmap child when our
- primary domain goes offline */
+ /* Send an online message to the idmap child when our
+ primary domain comes back online */
if ( domain->primary ) {
struct winbindd_child *idmap = idmap_child();